@@ -62,37 +62,63 @@ class FlureeConn(metaclass=jsii.JSIIMeta, jsii_type="fluree-jsii.FlureeConn"):
         '''
         return typing.cast(typing.Any, jsii.ainvoke(self, "connect", []))
 
-    @jsii.member(jsii_name="db")
-    def db(self, db_name: builtins.str) -> typing.Any:
+    @jsii.member(jsii_name="getDb")
+    def get_db(self, ledger: builtins.str) -> typing.Any:
         '''
-        :param db_name: -
-
-        :stability: experimental
-        '''
-        return typing.cast(typing.Any, jsii.ainvoke(self, "db", [db_name]))
-
-    @jsii.member(jsii_name="query")
-    def query(self, q: typing.Any) -> typing.Any:
-        '''
-        :param q: -
-
-        :stability: experimental
-        '''
-        return typing.cast(typing.Any, jsii.ainvoke(self, "query", [q]))
-
-    @jsii.member(jsii_name="transact")
-    def transact(
-        self,
-        q: typing.Sequence[typing.Any],
-        ledger: builtins.str,
-    ) -> typing.Any:
-        '''
-        :param q: -
         :param ledger: -
 
         :stability: experimental
         '''
-        return typing.cast(typing.Any, jsii.ainvoke(self, "transact", [q, ledger]))
+        return typing.cast(typing.Any, jsii.ainvoke(self, "getDb", [ledger]))
+
+    @jsii.member(jsii_name="ledgerList")
+    def ledger_list(self) -> typing.Any:
+        '''
+        :stability: experimental
+        '''
+        return typing.cast(typing.Any, jsii.ainvoke(self, "ledgerList", []))
+
+    @jsii.member(jsii_name="newLedger")
+    def new_ledger(self, name: builtins.str) -> typing.Any:
+        '''
+        :param name: -
+
+        :stability: experimental
+        '''
+        return typing.cast(typing.Any, jsii.ainvoke(self, "newLedger", [name]))
+
+    @jsii.member(jsii_name="query")
+    def query(self, ledger: builtins.str, query: typing.Any) -> typing.Any:
+        '''
+        :param ledger: -
+        :param query: -
+
+        :stability: experimental
+        '''
+        return typing.cast(typing.Any, jsii.ainvoke(self, "query", [ledger, query]))
+
+    @jsii.member(jsii_name="transact")
+    def transact(
+        self,
+        ledger: builtins.str,
+        transaction: typing.Sequence[typing.Any],
+    ) -> typing.Any:
+        '''
+        :param ledger: -
+        :param transaction: -
+
+        :stability: experimental
+        '''
+        return typing.cast(typing.Any, jsii.ainvoke(self, "transact", [ledger, transaction]))
+
+    @jsii.member(jsii_name="waitUntilReady")
+    def wait_until_ready(self, name: builtins.str) -> typing.Any:
+        '''
+        :param name: -
+
+        :stability: experimental
+        '''
+        return typing.cast(typing.Any, jsii.ainvoke(self, "waitUntilReady", [name]))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="conn")
